# KWN-Precipitation

Python library for performing precipitation simulations using the Kampmann-Wagner Numerical (KWN) model. This package allows for coupling with pycalphad to perform thermodynamic and kinetic calculations.

Required Dependencies:
    numpy, scipy, matplotlib, pycalphad